==> lifetype-1.1.tbz: www/lifetype/plugins/secretblog/class/action/adminsecretblogpluginupdatesettingsaction.class.php <==
<?php

	include_once( PLOG_CLASS_PATH."class/action/admin/blogowneradminaction.class.php" );
	include_once( PLOG_CLASS_PATH."plugins/secretblog/class/view/adminsecretblogpluginsettingsview.class.php" );	
	include_once( PLOG_CLASS_PATH."class/dao/blogs.class.php" );
	
    class AdminSecretBlogPluginUpdateSettingsAction extends BlogOwnerAdminAction 
	{
	
		var $_pluginEnabled;
		var $_blogPassword;

    	/**
         * Constructor. If nothing else, it also has to call the constructor of the parent
         * class, BlogAction with the same parameters
         */
        function AdminSecretBlogPluginUpdateSettingsAction( $actionInfo, $request )
        {
        	$this->BlogOwnerAdminAction( $actionInfo, $request );
        }
		
		function validate()
		{
            $this->_pluginEnabled = $this->_request->getValue( "pluginEnabled" );
            $this->_pluginEnabled = ($this->_pluginEnabled != "" );			
            
            $this->_blogPassword = $this->_request->getValue( "blogPassword" );
			
			return true;
		}	

        /**
         * Carries out the specified action
         */
        function perform()
        {
            // update the plugin configurations to blog setting
			$blogSettings = $this->_blogInfo->getSettings();
            $blogSettings->setValue( "plugin_secretblog_enabled", $this->_pluginEnabled );
            // only update the password if it's not empty, or else leave it as it is
            if( $this->_blogPassword != "" ) 
	            $blogSettings->setValue( "plugin_secretblog_password", md5( $this->_blogPassword ));
            $this->_blogInfo->setSettings( $blogSettings ); 
			
			// save the blogs settings
			$blogs = new Blogs();
            if( !$blogs->updateBlog( $this->_blogInfo )) {
                $this->_view = new AdminSecretPluginSettingsView( $this->_blogInfo );
                $this->_view->setErrorMessage( $this->_locale->tr("error_updating_settings"));
                $this->setCommonData();

                return false;                
            }
			
			// if everything went ok...
            $this->_blogInfo->setSettings( $blogSettings );
            $this->_session->setValue( "blogInfo", $this->_blogInfo );
            $this->saveSession();
			
			$this->_view = new AdminSecretBlogPluginSettingsView( $this->_blogInfo );
			$this->_view->setSuccessMessage( $this->_locale->tr("secretblog_settings_saved_ok"));			
			$this->setCommonData();
			
			// clear the cache
			CacheControl::resetBlogCache( $this->_blogInfo->getId());			
            
            return true;	            
        }
    }
?>

==> lifetype-1.2.11.tbz: www/lifetype/plugins/secretblog/class/action/adminsecretblogpluginupdatesettingsaction.class.php <==
<?php

	lt_include( PLOG_CLASS_PATH."class/action/admin/adminaction.class.php" );
//	lt_include( PLOG_CLASS_PATH."class/action/admin/blogowneradminaction.class.php" );
	lt_include( PLOG_CLASS_PATH."plugins/secretblog/class/view/adminsecretblogpluginsettingsview.class.php" );	
	lt_include( PLOG_CLASS_PATH."class/dao/blogs.class.php" );
	
    class AdminSecretBlogPluginUpdateSettingsAction extends AdminAction 
	{
	
		var $_pluginEnabled;
		var $_blogPassword;

    	/**
         * Constructor. If nothing else, it also has to call the constructor of the parent
         * class, BlogAction with the same parameters
         */
        function AdminSecretBlogPluginUpdateSettingsAction( $actionInfo, $request )
        {
        	$this->AdminAction( $actionInfo, $request );
			$this->requirePermission( "manage_plugins" );
        }
		
		function validate()
		{
            $this->_pluginEnabled = $this->_request->getValue( "pluginEnabled" );
            $this->_pluginEnabled = ($this->_pluginEnabled != "" );			
            
            $this->_blogPassword = $this->_request->getValue( "blogPassword" );
			
			return true;
		}	

        /**
         * Carries out the specified action
         */
        function perform()
        {
            // update the plugin configurations to blog setting
			$blogSettings = $this->_blogInfo->getSettings();
            $blogSettings->setValue( "plugin_secretblog_enabled", $this->_pluginEnabled );
            // only update the password if it's not empty, or else leave it as it is
            if( $this->_blogPassword != "" ) 
	            $blogSettings->setValue( "plugin_secretblog_password", md5( $this->_blogPassword ));
            $this->_blogInfo->setSettings( $blogSettings ); 
			
			// save the blogs settings
			$blogs = new Blogs();
            if( !$blogs->updateBlog( $this->_blogInfo )) {
                $this->_view = new AdminSecretPluginSettingsView( $this->_blogInfo );
                $this->_view->setErrorMessage( $this->_locale->tr("error_updating_settings"));
                $this->setCommonData();

                return false;                
            }
			
			// if everything went ok...
            $this->_blogInfo->setSettings( $blogSettings );
            $this->_session->setValue( "blogInfo", $this->_blogInfo );
            $this->saveSession();
			
			$this->_view = new AdminSecretBlogPluginSettingsView( $this->_blogInfo );
			$this->_view->setSuccessMessage( $this->_locale->tr("secretblog_settings_saved_ok"));			
			$this->setCommonData();
			
			// clear the cache
			CacheControl::resetBlogCache( $this->_blogInfo->getId());			
            
            return true;	            
        }
    }
?>
